# Test Coverage Report: excluded packages and modules

Generated: Fri 2013-09-20 15:24 CEST

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- cms
- django.contrib.admin
- django.contrib.admindocs
- django.contrib.auth
- django.contrib.contenttypes
- django.contrib.sessions
- django.contrib.sitemaps
- django.contrib.sites
- django.contrib.staticfiles
- frequently.admin
- frequently.cms_app
- frequently.cms_plugins
- frequently.fixtures
- frequently.migrations
- frequently.templatetags.__init__
- frequently.tests
- frequently.tests.test_app.__init__
- frequently.tests.test_app.models
- frequently.urls
- menus
- mptt
- sekizai

Back to index.